@@ -1,9 +1,9 @@
 package lib::noop;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-05-20'; # DATE
+our $DATE = '2021-06-07'; # DATE
 our $DIST = 'lib-noop'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use strict;
 use warnings;
@@ -51,7 +51,7 @@ lib::noop - no-op loading of some modules
 
 =head1 VERSION
 
-This document describes version 0.005 of lib::noop (from Perl distribution lib-noop), released on 2021-05-20.
+This document describes version 0.006 of lib::noop (from Perl distribution lib-noop), released on 2021-06-07.
 
 =head1 SYNOPSIS
 
@@ -96,6 +96,12 @@ entry first:
 
 =for Pod::Coverage .+
 
+=head1 CONTRIBUTOR
+
+=for stopwords perlancar (on netbook-dell-xps13)
+
+perlancar (on netbook-dell-xps13) <perlancar@gmail.com>
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/lib-noop>.
@@ -106,7 +112,7 @@ Source repository is at L<https://github.com/perlancar/perl-lib-noop>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-lib-noop/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=lib-noop>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
